import { McpError } from '@modelcontextprotocol/sdk/types.js';
import { testConfig } from '../../config.js';
// Track created test resources
let testResources = {
    decks: new Set(),
    noteIds: new Set(),
    noteTypes: new Set()
};
// Initialize test tracking
export function initializeTestTracking() {
    testResources = {
        decks: new Set(),
        noteIds: new Set(),
        noteTypes: new Set()
    };
}
// Clean up test resources
export async function cleanupTestResources(ankiConnect) {
    // Delete all test notes
    if (testResources.noteIds.size > 0) {
        await ankiConnect.deleteNotes({ notes: Array.from(testResources.noteIds) });
    }
    // Delete all test decks
    for (const deck of testResources.decks) {
        try {
            await ankiConnect.deleteDeck(deck);
        }
        catch (error) {
            console.error(`Failed to delete deck ${deck}:`, error);
        }
    }
    // Reset tracking
    initializeTestTracking();
}
export function createTestDeck() {
    const deck = {
        name: `test_deck_${Date.now()}_${Math.random().toString(36).substring(7)}`
    };
    testResources.decks.add(deck.name);
    return deck;
}
export function createTestBasicNote(deckName) {
    const timestamp = Date.now();
    const [basic, test] = testConfig.test.tags.basic.split(',');
    return {
        deck: deckName,
        front: `Test Front ${timestamp}`,
        back: `Test Back ${timestamp}`,
        tags: [test, basic, `test_${timestamp}`]
    };
}
export function createTestClozeNote(deckName) {
    const timestamp = Date.now();
    const [cloze, test] = testConfig.test.tags.cloze.split(',');
    return {
        deck: deckName,
        text: `This is a {{c1::cloze deletion}} test ${timestamp}`,
        backExtra: `Additional back content ${timestamp}`,
        tags: [test, cloze, `test_${timestamp}`]
    };
}
export function createTestNoteType() {
    const name = `test_note_type_${Date.now()}_${Math.random().toString(36).substring(7)}`;
    testResources.noteTypes.add(name);
    return {
        name,
        fields: [...testConfig.test.fields.basic],
        css: testConfig.test.defaultCss,
        templates: [testConfig.test.templates.basic]
    };
}
export function expectError(error, message) {
    expect(error).toBeInstanceOf(McpError);
    if (message) {
        expect(error.message).toContain(message);
    }
}
