/**
 * Anki server configuration
 */
export declare const config: {
    /**
     * Anki-Connect service URL
     */
    readonly ankiConnectUrl: "http://localhost:8765";
    /**
     * Anki-Connect API version
     */
    readonly apiVersion: 6;
    /**
     * Default deck name
     */
    readonly defaultDeck: "Default";
    /**
     * Note model configuration
     */
    readonly noteModels: {
        readonly basic: {
            readonly en: "Basic";
            readonly zh: "基础";
        };
        readonly cloze: {
            readonly en: "Cloze";
            readonly zh: "填空题";
        };
    };
    /**
     * Request configuration
     */
    readonly request: {
        /**
         * Request timeout in milliseconds
         */
        readonly timeout: 5000;
        /**
         * Retry timeout in milliseconds
         */
        readonly retryTimeout: 10000;
        /**
         * Headers
         */
        readonly headers: {
            readonly 'Content-Type': "application/json";
            readonly Accept: "application/json";
            readonly Connection: "keep-alive";
        };
    };
};
/**
 * Test-specific configuration
 */
export declare const testConfig: {
    readonly test: {
        /**
         * Default CSS for test note types
         */
        readonly defaultCss: ".card { font-family: arial; }";
        /**
         * Default tags for test notes
         */
        readonly tags: {
            readonly basic: "test,basic";
            readonly cloze: "test,cloze";
        };
        /**
         * Default field names for test note types
         */
        readonly fields: {
            readonly basic: readonly ["正面", "背面"];
        };
        /**
         * Default card templates
         */
        readonly templates: {
            readonly basic: {
                readonly name: "Card 1";
                readonly front: "{{正面}}";
                readonly back: "{{FrontSide}}<hr id=\"answer\">{{背面}}";
            };
        };
    };
    /**
     * Anki-Connect service URL
     */
    readonly ankiConnectUrl: "http://localhost:8765";
    /**
     * Anki-Connect API version
     */
    readonly apiVersion: 6;
    /**
     * Default deck name
     */
    readonly defaultDeck: "Default";
    /**
     * Note model configuration
     */
    readonly noteModels: {
        readonly basic: {
            readonly en: "Basic";
            readonly zh: "基础";
        };
        readonly cloze: {
            readonly en: "Cloze";
            readonly zh: "填空题";
        };
    };
    /**
     * Request configuration
     */
    readonly request: {
        /**
         * Request timeout in milliseconds
         */
        readonly timeout: 5000;
        /**
         * Retry timeout in milliseconds
         */
        readonly retryTimeout: 10000;
        /**
         * Headers
         */
        readonly headers: {
            readonly 'Content-Type': "application/json";
            readonly Accept: "application/json";
            readonly Connection: "keep-alive";
        };
    };
};
